@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -46,7 +46,7 @@ AuditLogViewer::AuditLogViewer(const QString &log, QWidget *parent)
       m_textEdit(new QTextEdit(this))
 #endif
 {
-    setWindowTitle(i18n("View GnuPG Audit Log"));
+    setWindowTitle(i18nc("@title:window", "View GnuPG Audit Log"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
 
     QPushButton *copyClipBtn = new QPushButton;
@@ -108,7 +108,7 @@ void AuditLogViewer::slotSaveAs()
         }
         s << "</head><body>\n"
           << m_log
-          << "\n</body></html>" << endl;
+          << "\n</body></html>\n";
         s.flush();
         file.commit();
     }
